==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/space/messages/ko/manage.php <==
<?php
return array (
  '-' => '',
  '<strong>Confirm</strong> image deleting' => '',
  '<strong>Create</strong> new space' => '',
  '<strong>Manage</strong> members' => '',
  '<strong>Members</strong>' => '',
  '<strong>Modify</strong> space image' => '',
  '<strong>Security</strong> settings' => '',
  '<strong>Space</strong> Modules' => '',
  '<strong>Space</strong> settings' => '',
  'Actions' => '',
  'Activated' => '',
  'Add <strong>Modules</strong>' => '',
  'Advanced access settings' => '',
  'Archive' => '',
  'Are you sure, that you want to delete this space? All published content will be removed!' => '',
  'Are you sure? *ALL* module data for this space will be deleted!' => '',
  'As owner of this space you can transfer this role to another administrator in space.' => '',
  'Cancel' => '',
  'Cancel Membership' => '',
  'Choose if new content should be public or private by default' => '',
  'Choose the kind of membership you want to provide for this workspace.' => '',
  'Choose the security level for this workspace to define the visibleness.' => '',
  'Close' => '닫기',
  'Configure' => '',
  'Currently there are no modules available for this space!' => '',
  'Delete' => '',
  'Disable' => '',
  'Do you really want to delete your profile image?' => '',
  'Do you really want to delete your title image?' => '',
  'Don\'t receive notifications for new content' => '',
  'Enable' => '',
  'Enhance this space with modules.' => '',
  'Hide posts on dashboard' => '',
  'Invited By' => '',
  'Members' => '',
  'Modules' => '',
  'Next' => '',
  'Owner' => '',
  'Pending Approvals' => '',
  'Pending Invites' => '',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => '',
  'Please provide your password to continue!' => '',
  'Receive Notifications for new content' => '',
  'Remove from space' => '',
  'Role' => '',
  'Save' => '',
  'Security' => '',
  'Send & decline' => '',
  'Show all' => '',
  'Show posts on dashboard' => '',
  'Space name' => '',
  'Space owner' => '',
  'Stream (Default)' => '',
  'The url contains illegal characters!' => '',
  'This option will hide new content from this space at your dashboard' => '',
  'This option will show new content from this space at your dashboard' => '',
  'Transfer ownership' => '',
  'Unarchive' => '',
  'Your password' => '',
  'e.g. example for {baseUrl}/s/example' => '',
  'never' => '',
  'space description' => '',
  'the default start page of this space for members' => '',
  'the default start page of this space for visitors' => '',
);

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/space/messages/ko/manage.php <==
<?php
return array (
  '-' => '',
  '<strong>Create</strong> Space' => '',
  '<strong>Manage</strong> members' => '',
  '<strong>Members</strong>' => '',
  '<strong>Security</strong> settings' => '',
  '<strong>Space</strong> Modules' => '',
  '<strong>Space</strong> settings' => '',
  'Actions' => '확인',
  'Activate' => '활성화',
  'Add <strong>Modules</strong>' => '',
  'Advanced access settings' => '',
  'All members excluding moderators and administrators of this Space will be removed. All pending invitations and membership requests will be terminated.' => '',
  'Archive' => '',
  'Are you sure you want to remove this member.' => '',
  'Are you sure, that you want to delete this space? All published content will be removed!' => '',
  'As owner of this space you can transfer this role to another administrator in space.' => '',
  'Cancel Membership' => '',
  'Choose if new content should be public or private by default' => '',
  'Choose the kind of membership you want to provide for this workspace.' => '',
  'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => '',
  'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => '',
  'Choose the security level for this workspace to define the visibleness.' => '',
  'Currently there are no modules available for this space!' => '',
  'Delete' => '삭제',
  'Don\'t receive notifications for new content' => '',
  'Hide posts on dashboard' => '',
  'Invited By' => '',
  'Members' => '',
  'Modules' => '모듈',
  'Next' => '다음',
  'Only global administrators can change this value' => '',
  'Owner' => '',
  'Pending Approvals' => '',
  'Pending Invites' => '',
  'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => '',
  'Please type the name of the space to proceed.' => '',
  'Receive Notifications for new content' => '',
  'Removal of members queued' => '',
  'Remove all members' => '',
  'Remove from space' => '',
  'Role' => '',
  'Security' => '',
  'Show all' => '',
  'Show posts on dashboard' => '',
  'Space name' => '',
  'Space owner' => '',
  'Stream (Default)' => '',
  'The URL has already been taken.' => '',
  'The url contains illegal characters!' => '',
  'This option will hide new content from this space at your dashboard' => '',
  'This option will show new content from this space at your dashboard' => '',
  'Transfer ownership' => '',
  'Unarchive' => '',
  'e.g. example for {baseUrl}/s/example' => '',
  'never' => '',
);
